@@ -28,7 +28,7 @@ public:
 
 void ConfigDialogPrivate::slotConfigChanged()
 {
-    emit q->languageChanged(ui->language());
+    Q_EMIT q->languageChanged(ui->language());
 }
 
 ConfigDialog::ConfigDialog(QWidget *parent)
