@@ -19,14 +19,14 @@ public:
     {
     }
 
-    DictionaryComboBox *q;
+    DictionaryComboBox *const q;
     void slotDictionaryChanged(int idx);
 };
 
 void DictionaryComboBoxPrivate::slotDictionaryChanged(int idx)
 {
-    emit q->dictionaryChanged(q->itemData(idx).toString());
-    emit q->dictionaryNameChanged(q->itemText(idx));
+    Q_EMIT q->dictionaryChanged(q->itemData(idx).toString());
+    Q_EMIT q->dictionaryNameChanged(q->itemText(idx));
 }
 
 //@endcon
